# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/ZoneObjectStatus.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import genpy

class ZoneObjectStatus(genpy.Message):
  _md5sum = "8772b83ae4bd9c1cd4909050418563b0"
  _type = "digitaleye_msgs/ZoneObjectStatus"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Status of the object within the specified zone

# identifier of the zone the object is in
uint32 zone_id

# whether or not the object is allowed in the zone
bool allowed

# time the object was first detected in this zone
# (ros timestamp in epoch time)
time first_detected

# time the object was last detected in this zone
# (ros timestamp in epoch time)
time last_detected
"""
  __slots__ = ['zone_id','allowed','first_detected','last_detected']
  _slot_types = ['uint32','bool','time','time']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       zone_id,allowed,first_detected,last_detected

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(ZoneObjectStatus, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.zone_id is None:
        self.zone_id = 0
      if self.allowed is None:
        self.allowed = False
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
    else:
      self.zone_id = 0
      self.allowed = False
      self.first_detected = genpy.Time()
      self.last_detected = genpy.Time()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_IB4I().pack(_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
      end = 0
      _x = self
      start = end
      end += 21
      (_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs,) = _get_struct_IB4I().unpack(str[start:end])
      self.allowed = bool(self.allowed)
      self.first_detected.canon()
      self.last_detected.canon()
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_IB4I().pack(_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.first_detected is None:
        self.first_detected = genpy.Time()
      if self.last_detected is None:
        self.last_detected = genpy.Time()
      end = 0
      _x = self
      start = end
      end += 21
      (_x.zone_id, _x.allowed, _x.first_detected.secs, _x.first_detected.nsecs, _x.last_detected.secs, _x.last_detected.nsecs,) = _get_struct_IB4I().unpack(str[start:end])
      self.allowed = bool(self.allowed)
      self.first_detected.canon()
      self.last_detected.canon()
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_IB4I = None
def _get_struct_IB4I():
    global _struct_IB4I
    if _struct_IB4I is None:
        _struct_IB4I = struct.Struct("<IB4I")
    return _struct_IB4I
